/***** dnaDist.c **********************************
 * Description: 
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Mon Jun  1 16:43:51 2015
 **************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>
#include "gsl_rng.h"
#include "sequenceData.h"
#include "alignment.h"
#include "interface.h"
#include "eprintf.h"
#include "distance.h"

void runAnalysis(Args *args, int fd){
  gsl_rng *r;
  int i;
  Sequence *seq;
  Alignment *al;

  seq = readFasta(fd);
  al = seq2al(seq);
  jukesCantor(al);
  printDist(al);
  if(args->b || args->p){
    r = ini_gsl_rng(args);
    for(i=0;i<args->b-1;i++){
      jukesCantorBoot(al,r);
      printDist(al);
    }
    for(i=0;i<args->p-1;i++){
      jukesCantorPairBoot(al,r);
      printDist(al);
    }
    free_gsl_rng(r,args);
  }
  freeSequence(seq);
  freeAlignment(al);
}

int main(int argc, char *argv[]){
  int i, fd;
  char *version;
  Args *args;

  version = "0.4";
  setprogname2("dnaDist");
  args = getArgs(argc, argv);
  if(args->v)
    printSplash(version);
  if(args->h || args->e)
    printUsage(version);
  if(args->numInputFiles){
    for(i=0;i<args->numInputFiles;i++){
      fd = open(args->inputFiles[i],O_RDONLY,0);
      runAnalysis(args,fd);
      close(fd);
    }
  }else{
    fd = 0;
    runAnalysis(args,fd);
  }
  free(args);
  free(progname());
  return 0;
}

